@@ -25,7 +25,7 @@ SEXP string_box(SEXP string)
       int str_subwidth = 0;
       int str_height= 0;
 
-      char *substring = CHAR(STRING_ELT(string, i));
+      const char *substring = CHAR(STRING_ELT(string, i));
       
       j = 0;
       
